@@ -5,6 +5,7 @@ import pytest
 
 from python_minifier import unparse
 from python_minifier.ast_compare import compare_ast
+from python_minifier.ast_printer import print_ast
 from python_minifier.rename import add_namespace, bind_names, resolve_names, rename, rename_literals, allow_rename_locals, allow_rename_globals
 
 def hoist(source):
@@ -491,3 +492,28 @@ c = A + A
     expected_ast = ast.parse(expected)
     actual_ast = hoist(source)
     compare_ast(expected_ast, actual_ast)
+
+def test_no_hoist_slots():
+    source = '''
+class SlotsA(object):
+    __slots__ = ['aaaaa', 'bbbbb']
+    notslots = ['aaaaa']
+class SlotsB(object):
+    __slots__ = 'aaaaa', 'bbbbb'
+    notslots = ['aaaaa']
+'''
+    expected = '''
+A = 'aaaaa'
+class SlotsA(object):
+    __slots__ = ['aaaaa', 'bbbbb']
+    notslots = [A]
+class SlotsB(object):
+    __slots__ = 'aaaaa', 'bbbbb'
+    notslots = [A]
+'''
+    expected_ast = ast.parse(expected)
+    actual_ast = hoist(source)
+
+    print(print_ast(expected_ast))
+    print(print_ast(actual_ast))
+    compare_ast(expected_ast, actual_ast)
